@@ -913,7 +913,7 @@ print(x$call)
 cat("\n")
 cat("\nFixed Effects:\n")
 cat("\nCoefficients:\n")
-printCoefmat(x$coefficients, P.value=TRUE, has.Pvalue=TRUE)
+printCoefmat(x$coefficients, P.values=TRUE, has.Pvalue=TRUE)
 cat("\nForced Smooth Effects:\n")
 print(x$U.fix.names)
 cat("\nSelected Smooth Effects:\n")
